pigz version 2.6
diff --git a/README b/README
index c880cd5..7791744 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-pigz 2.5 (23 Jan 2021) by Mark Adler
+pigz 2.6 (6 Feb 2021) by Mark Adler
 
 pigz, which stands for Parallel Implementation of GZip, is a fully functional
 replacement for gzip that exploits multiple processors and multiple cores to
diff --git a/pigz.1 b/pigz.1
index b292fbd..c6a4950 100644
--- a/pigz.1
+++ b/pigz.1
@@ -1,4 +1,4 @@
-.TH PIGZ 1 "January 23, 2021"
+.TH PIGZ 1 "February 6, 2021"
 .SH NAME
 pigz, unpigz \- compress or expand files
 .SH SYNOPSIS
@@ -136,6 +136,9 @@
 .B -c --stdout --to-stdout
 Write all processed output to stdout (won't delete).
 .TP
+.B -C --comment ccc
+Include the provided comment in the gzip header or zip central file header.
+.TP
 .B -d --decompress --uncompress
 Decompress the compressed input.
 .TP
@@ -145,6 +148,9 @@
 .B -h --help
 Display a help screen and quit.
 .TP
+.B -H --huffman
+Compress using the Huffman-only strategy.
+.TP
 .B -i --independent
 Compress blocks independently for damage recovery.
 .TP
@@ -183,9 +189,6 @@
 Store or restore both the file name and the modification time. This is the
 default when compressing.
 .TP
-.B -C --comment ccc
-Include the provided comment in the gzip header or zip central file header.
-.TP
 .B -p --processes n
 Allow up to n processes (default is the number of online processors)
 .TP
@@ -204,6 +207,9 @@
 .B -t --test
 Test the integrity of the compressed input.
 .TP
+.B -U --rle
+Compress using the run length encoding strategy.
+.TP
 .B -v --verbose
 Provide more verbose output.
 .TP
diff --git a/pigz.pdf b/pigz.pdf
index ae52a17..d44da23 100644
--- a/pigz.pdf
+++ b/pigz.pdf
Binary files differ
diff --git a/pigz.spec b/pigz.spec
index 955e197..5ebd1ac 100644
--- a/pigz.spec
+++ b/pigz.spec
@@ -1,6 +1,6 @@
 Summary: pigz is a parallel implementation of gzip which utilizes multiple cores
 Name: pigz
-Version: 2.5
+Version: 2.6
 Release: 1
 Source0: %{name}-%{version}.tar.gz
 License: zlib
diff --git a/pigz.c b/pigz.c
index 7a97692..f90157f 100644
--- a/pigz.c
+++ b/pigz.c
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2021 Mark Adler
  * Version 2.5  23 Jan 2021  Mark Adler
  */
 
 /*
@@ -195,9 +195,12 @@
                        Do not reject .zip entries with bit 11 set
                        Avoid a possible threads lock-order inversion
                        Ignore trailing junk after a gzip stream by default
+   2.6     6 Feb 2021  Add --huffman/-H and --rle/U strategy options
+                       Fix issue when compiling for no threads
+                       Fail silently on a broken pipe
  */
 
-#define VERSION "pigz 2.5"
+#define VERSION "pigz 2.6"
 
 /* To-do:
     - make source portable for Windows, VMS, etc. (see gzip source code)
@@ -1,6 +1,6 @@
 /* pigz.c -- parallel implementation of gzip
  * Copyright (C) 2007-2021 Mark Adler
- * Version 2.5  23 Jan 2021  Mark Adler
+ * Version 2.6  6 Feb 2021  Mark Adler
  */
 